#
# spec file for package python-python-whois
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-python-whois
Version:        0.9.5
Release:        1.1
Summary:        Whois querying and parsing of domain registration information
License:        MIT
URL:            https://github.com/richardpenman/whois
Source:         https://files.pythonhosted.org/packages/source/p/python_whois/python_whois-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module simplejson}
# /SECTION
BuildRequires:  fdupes
Requires:       python-python-dateutil
BuildArch:      noarch
%python_subpackages

%description
A simple importable Python module which will produce parsed WHOIS data for a given domain.
Able to extract data for all the popular TLDs (com, org, net, ...)
Query a WHOIS server directly instead of going through an intermediate web service like many others do.

%prep
%autosetup -p1 -n python_whois-%{version}
# requires internet connection:
rm test/test_query.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_ipv4 test_ipv6 - online check
# test_il_parse - online check
# test_choose_server - online check
%pytest -k 'not (test_ipv4 or test_ipv6 or test_il_parse or test_choose_server)'

%files %{python_files}
%doc README.md
%{python_sitelib}/whois
%{python_sitelib}/python_whois-%{version}.dist-info

%changelog
* Fri Jan 10 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.9.5
  * Add studio host
  * Case-insensitively avoid duplicate attribute values
  * Updated test expected values
  * Add registrar_url for base entry
  * Update expected samples
  * This addresses #223 while trying to be backwards compatible
    with the old format just in case ...
  * Enhancements for .jp domains
  * Fix exception
  * Fix datetime.UTC, which doesn't work on all versions of Py3
  * Update WhoisSg to address #222
  * Adding a quick timeout option to whois.whois()
  * Handle "before YYYY" entries to fix #228
  * Standardize test assertions for sample files
  * Create test case sample for .sg domain
  * Update WhoisSG parser to grab status, updated_date, dnssec and ns
  * Add .live domain server config and sample
  * Move socket creation to external func, to reuse it in findwhois_iana with proxy
  * Add parsing for .lv domains
  * Added the "Reseller" field to the parser.
  * tr domains not support idna encoded decoded whois requests
  * Set request for tr domains without idna
  * Quick fix for tr domain
  * Add convert_punycode flag
  * Remove .DS_Store
  * Quick-fix
  * Fix tests
  * Update parser.py with created for .de
- from version 0.9.4
  * Complete the regex for parsing the WHOIS response results for .jp domains.
  * Bump ci actions
  * Fix regex for parsing .pl nameservers
  * Update and rename README.rst to README.md
  * Update README.md
  * Added support for markdown in setup and bumped version
  * Fixed .ru used correct nic server
- Adjust upstream source name in spec file
- Rename README.rst to README.md in %%files section
* Sun Apr 21 2024 Dirk Müller <dmueller@suse.com>
- update to 0.9.3:
  * dateutil is required dependency
  * remove futures reference
  * remove support for python 2
  * adding default TZ as UTC if none specified
  * fix parsing whois response for jp domains
- drop remove-future-requirement.patch (upstream)
* Tue Sep 12 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch remove-future-requirement.patch, remove future requirement
- Switch to autosetup and pyproject macros
- Stop using greedy globs in %%files
* Tue Aug  9 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to 0.8.0:
  - no changelog available
- disable failing Python2 build.
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.2:
  * no changelog available
* Fri May  3 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.7.1:
  * no changelog available
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Apr 29 2018 sebix+novell.com@sebix.at
- update to version 0.7.0:
  * support for .lu, cz
  * fix for .eu
* Wed Mar 21 2018 sebix+novell.com@sebix.at
- update typo version 0.6.9:
  * fix .me
- update typo version 0.6.8:
  * support for .cat, .ie, .space, .nz
  * dealing with multiple dates improved
  * fixes for Python 3
* Thu Dec  7 2017 sebix+novell.com@sebix.at
- initial package for version 0.6.7
